/**
Static list of the Node.js builtin modules.

@example
```
import builtinModulesStatic = require('builtin-modules/static');

console.log(builtinModulesStatic);
//=> ['assert', 'buffer', …]
```
*/
declare const builtinModulesStatic: readonly string[];

export = builtinModulesStatic;
